@@ -11,10 +11,10 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.866';
+our $VERSION = '1.874';
 
 use base 'MCE::Mutex';
-use Scalar::Util qw(refaddr weaken);
+use Scalar::Util qw(weaken);
 use MCE::Util ();
 
 my $tid = $INC{'threads.pm'} ? threads->tid() : 0;
@@ -30,8 +30,6 @@ sub DESTROY {
     syswrite($obj->{_r_sock}, '0'), $obj->{$pid.'b'} = 0 if $obj->{$pid.'b'};
 
     if ( $obj->{_init_pid} eq $pid ) {
-        my $addr = refaddr $obj;
-
         ($^O eq 'MSWin32' && $obj->{impl} eq 'Channel')
             ? MCE::Util::_destroy_pipes($obj, qw(_w_sock _r_sock))
             : MCE::Util::_destroy_socks($obj, qw(_w_sock _r_sock));
@@ -70,7 +68,7 @@ sub new {
 
     ($^O eq 'MSWin32')
         ? MCE::Util::_pipe_pair(\%obj, qw(_r_sock _w_sock))
-        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock));
+        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock), undef, 1);
 
     syswrite $obj{_w_sock}, '0';
 
@@ -84,7 +82,7 @@ sub new {
 }
 
 sub lock {
-    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
     MCE::Util::_sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
@@ -96,27 +94,29 @@ sub lock {
 *lock_shared    = \&lock;
 
 sub unlock {
-    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
-    syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0
+    CORE::syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0
         if $obj->{ $pid };
 
     return;
 }
 
 sub synchronize {
-    my ($pid, $obj, $code, @ret) = ($tid ? $$ .'.'. $tid : $$, shift, shift);
+    my ($pid, $obj, $code) = ($tid ? $$ .'.'. $tid : $$, shift, shift);
+    my (@ret, $b);
+
     return unless ref($code) eq 'CODE';
 
     # lock, run, unlock - inlined for performance
-    MCE::Util::_sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
+    MCE::Util::_sysread($obj->{_r_sock}, $b, 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
 
     (defined wantarray)
       ? @ret = wantarray ? $code->(@_) : scalar $code->(@_)
       : $code->(@_);
 
-    syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0;
+    CORE::syswrite($obj->{_w_sock}, '0'), $obj->{ $pid } = 0;
 
     return wantarray ? @ret : $ret[-1];
 }
@@ -139,7 +139,7 @@ MCE::Mutex::Channel - Mutex locking via a pipe or socket
 
 =head1 VERSION
 
-This document describes MCE::Mutex::Channel version 1.866
+This document describes MCE::Mutex::Channel version 1.874
 
 =head1 DESCRIPTION
 
